# depro  
a package for Decomposition profile data analysis to grasp the effects of small compounds.  

# Dependency  
* python 3.6  
* requirements: numpy, pandas, scipy, tqdm, enan  
  
# Setup  
`pip install depro`  
* for conda environment, please use skeleton  
  
# Usage  
see samplecode.ipynb  
   
# Licence  
This software is released under the MIT License.  

# Authors  
MIZUNO Tadahaya

# References  
This package is inspired from the following brilliant databases and studies:  
* Nat Genet. 2003 Jul;34(3):267-73.  
* PNAS. October 25, 2005 102 (43) 15545-15550.  
* BMC Bioinformatics. 2013;128(14).  
* Enrichr: a comprehensive gene set enrichment analysis web server 2016 update. Nucleic Acids Research. 2016; gkw377 .  
* Science. 2006 Sep 29;313(5795):1929-35.  
* [MsigDB](https://www.gsea-msigdb.org/gsea/msigdb/index.jsp)  
* [EnrichR](https://amp.pharm.mssm.edu/Enrichr/)  
* [CMap](https://portals.broadinstitute.org/cmap/)  
Also our results:  
* Development of Orthogonal Linear Separation Analysis (OLSA) to Decompose Drug Effects into Basic Components. Mizuno T, Kinoshita S, Ito T, Maedera S, Kusuhara H., Sci Rep. 2019 Feb 12;9(1):1824. doi: 10.1038/s41598-019-38528-4.  

# Bug Report  
If you would like to report any bugs about this package, don't hesitate to create an issue on github here, or email me:  
* tadahaya@gmail.com  
* tadahaya@mol.f.u-tokyo.ac.jp  
* tadahaya@g.ecc.u-tokyo.ac.jp  

# To Do  
* prepare sample code
